@@ -95,7 +95,8 @@ ctrDb <- function(
 
   ## unprepared for other nodbi adapters so far
   stop("Please specify in parameter 'con' a database connection. ",
-       "crdata supports so far only src_mongo() and src_sqlite().")
+       "crdata supports so far only src_mongo() and src_sqlite().",
+       call. = FALSE)
 
 } # end ctrDb
 
@@ -519,8 +520,9 @@ ctrFindActiveSubstanceSynonyms <- function(activesubstance = "") {
   asx <- tmp[[1]]
   asx <- asx[!grepl(
     paste0("(more|synonyms|terms|", as, "|",
-           paste0(unlist(strsplit(as, " ")), collapse = "|"),
-           ")"), asx, ignore.case = TRUE)]
+           paste0(unlist(strsplit(as, " "), use.names = FALSE),
+                  collapse = "|"), ")"), asx,
+    ignore.case = TRUE)]
 
   # prepare and return output
   as <- c(as, asx)
@@ -998,7 +1000,7 @@ dbFindIdsUniqueTrials <- function(
       # a.1 - euctr in ctgov
       dupesA1 <- listofEUCTRids[["a2_eudract_number"]] %in% sub(
         ".*([0-9]{4}-[0-9]{6}-[0-9]{2}).*", # e.g. "EUDRACT-2004-000242-20"
-        "\\1", unlist(listofCTGOVids[["id_info"]]))
+        "\\1", unlist(listofCTGOVids[["id_info"]], use.names = FALSE))
       #
       if (verbose) {
         message(" - ", sum(dupesA1),
@@ -1020,7 +1022,7 @@ dbFindIdsUniqueTrials <- function(
       dupesC1 <- !is.na(
         listofEUCTRids[["a52_us_nct_clinicaltrialsgov_registry_number"]]) &
         listofEUCTRids[["a52_us_nct_clinicaltrialsgov_registry_number"]] %in%
-        unlist(listofCTGOVids[["id_info"]])
+        unlist(listofCTGOVids[["id_info"]], use.names = FALSE)
       #
       if (verbose) {
         message(
@@ -1035,7 +1037,7 @@ dbFindIdsUniqueTrials <- function(
           "a51_isrctn_international_standard_randomised_controlled_trial_number"]]) &
         listofEUCTRids[[
           "a51_isrctn_international_standard_randomised_controlled_trial_number"]] %in%
-        unlist(listofCTGOVids[["id_info"]])
+        unlist(listofCTGOVids[["id_info"]], use.names = FALSE)
       #
       if (verbose) {
         message(
@@ -1048,7 +1050,7 @@ dbFindIdsUniqueTrials <- function(
       dupesE1 <- !is.na(
         listofEUCTRids[["a41_sponsors_protocol_code_number"]]) &
         listofEUCTRids[["a41_sponsors_protocol_code_number"]] %in%
-        unlist(listofCTGOVids[["id_info"]])
+        unlist(listofCTGOVids[["id_info"]], use.names = FALSE)
       #
       if (verbose) {
         message(
@@ -1061,7 +1063,7 @@ dbFindIdsUniqueTrials <- function(
       dupesF1 <- vapply(
         listofCTGOVids[["id_info"]],
         function(x) !is.null(x[["nct_alias"]]) &&
-          any(unlist(x[["nct_alias"]]) %in%
+          any(unlist(x[["nct_alias"]], use.names = FALSE) %in%
                 listofCTGOVids[["_id"]]), logical(1L))
       #
       if (verbose) {
@@ -1240,7 +1242,7 @@ dbGetFieldsIntoDf <- function(fields = "",
         function(cell) {
 
           # get content
-          cell <- unlist(cell)
+          cell <- unlist(cell, use.names = FALSE)
 
           # check if string could be json
           if (grepl("[\\[{]", cell)) {
@@ -1363,7 +1365,8 @@ dbGetFieldsIntoDf <- function(fields = "",
                 # keep NULL elements in output
                 NULL
               } else {
-                if (is.atomic(unlist(i, recursive = FALSE))) {
+                if (is.atomic(
+                  unlist(i, recursive = FALSE, use.names = FALSE))) {
                   # e.g. for location_countries.country
                   unname(i)
                 } else {
@@ -1432,10 +1435,11 @@ dbGetFieldsIntoDf <- function(fields = "",
             )) {
           # concatenate (has to remain as sapply
           # because of different content types)
-          dfi[, 2] <- sapply(dfi[, 2],
-                             function(x)
-                               paste0(na.omit(unlist(x)),
-                                      collapse = " / "))
+          dfi[, 2] <- sapply(
+            dfi[, 2],
+            function(x)
+              paste0(na.omit(unlist(x, use.names = FALSE)),
+                     collapse = " / "))
           # inform user
           message("\r* Collapsed with '/' [1]: '", item, "'")
           # remove any extraneous columns
@@ -1469,16 +1473,16 @@ dbGetFieldsIntoDf <- function(fields = "",
         }
         #
         # - if each [,2] is a list with a single and the same element
-        if (all(vapply(dfi[, 2], function(i) is.null(i) | is.list(i), logical(1L))) &&
-            length(unique(unlist(sapply(
-              dfi[, 2],
-              function(i)
-                unique(gsub("[0-9]+$", "", names(unlist(i)))))))) <= 1L) {
+        if (all(vapply(
+          dfi[, 2], function(i) is.null(i) | is.list(i), logical(1L))) &&
+          length(unique(unlist(sapply(
+            dfi[, 2], function(i) unique(gsub("[0-9]+$", "", names(unlist(i))))
+              )))) <= 1L) {
           #
           dfi[, 2] <- vapply(
-            dfi[, 2],
-            function(i)
-              paste0(na.omit(unlist(i)), collapse = " / "), character(1L))
+            dfi[, 2], function(i) paste0(
+              na.omit(unlist(i, use.names = FALSE)),
+              collapse = " / "), character(1L))
           # inform user
           message("\r* Simplified or collapsed with '/' [3]: '", item, "'")
         }
@@ -1749,7 +1753,7 @@ dfTrials2Long <- function(df) {
   flattenDf <- function(x) {
     while (any(vapply(x, is.list, logical(1L)))) {
       x <- lapply(x, function(x) if (is.list(x)) x else list(x))
-      x <- unlist(x, recursive = FALSE)
+      x <- unlist(x, recursive = FALSE, use.names = TRUE)
     }
     x
   }
@@ -1831,16 +1835,16 @@ dfTrials2Long <- function(df) {
     paste0(names, ".", out[["name"]]))
 
   # name can have from 0 to about 6 number groups, get all
-  # and concatenate to oid like string such as "1.2.2.1.4"
+  # and concatenate to oid-like string such as "1.2.2.1.4"
   out[["identifier"]] <- vapply(
     stringi::stri_extract_all_regex(out[["name"]], "[0-9]+([.]|$)"),
-    function(i) paste0(gsub("[.]", "", i), collapse = "."),
-    character(1L))
+    function(i) paste0(gsub("[.]", "", i), collapse = "."), character(1L))
   out[["identifier"]] [out[["identifier"]] == "NA"] <- "0"
   message(". ", appendLF = FALSE)
 
   # remove numbers from variable name
-  out[["name"]] <- gsub("[0-9]+([.])|[0-9]+$|[.]?@attributes", "\\1", out[["name"]], perl = TRUE)
+  out[["name"]] <- gsub(
+    "[0-9]+([.])|[0-9]+$|[.]?@attributes", "\\1", out[["name"]], perl = TRUE)
 
   # remove any double separators
   out[["name"]] <- gsub("[.]+", ".", out[["name"]], perl = TRUE)
@@ -1943,12 +1947,12 @@ dfListExtractKey <- function(
   out <- lapply(
     list.key,
     function(k)
-      lapply(df[[k[1]]], # k[1] = "endPoints.endPoint" identifies
+      lapply(df[[k[1]]],
+             # k[1] = "endPoints.endPoint" identifies
              # the column in data frame with the list
-             function(l)
-               extractKey(unlist(l, recursive = TRUE),
-                          k[2]) # k[2] = "^title" identifies
-             # the key in the sublist
+             function(l) extractKey(
+               unlist(l, recursive = TRUE, use.names = TRUE), k[2])
+             # k[2] = "^title" identifies the key in the sublist
       ))
 
   out <- sapply(seq_along(list.key), function(li) {
@@ -1962,9 +1966,8 @@ dfListExtractKey <- function(
 
         data.frame(
           name = gsub("[-0-9]*$", "", # trailing number
-                      gsub("[^a-zA-Z0-9_.-]", "",
-                           paste0(list.key[[li]],
-                                  collapse = "."))),
+                 gsub("[^a-zA-Z0-9_.-]", "",
+                 paste0(list.key[[li]], collapse = "."))),
           "_id" = df[["_id"]][[ii]],
           value = tmp[[ii]],
           item = seq_along(tmp[[ii]]),
@@ -1977,11 +1980,8 @@ dfListExtractKey <- function(
 
   }, simplify = FALSE)
 
-  out <- do.call(rbind, out)
-  rownames(out) <- NULL
-
   # return
-  out
+  do.call(rbind, c(out, stringsAsFactors = FALSE, make.row.names = FALSE))
 
 } # end dfListExtractKey
 
@@ -2031,7 +2031,7 @@ dfMergeTwoVariablesRelevel <- function(
   tmp <- tmp["varnames"]
   tmp <- as.list(tmp)[[1]]
   if (length(tmp) == 3 && colnames == "") {
-    colnames <- unlist(as.list(tmp[-1]))
+    colnames <- unlist(as.list(tmp[-1], use.names = FALSE))
     warning("Parameter varnames is deprecated, use colnames instead.",
             call. = FALSE)
   }
@@ -2092,7 +2092,7 @@ dfMergeTwoVariablesRelevel <- function(
 
     # apply helperfunction to elements of the list
     for (i in seq_len(length(levelslist))) {
-      tmp <- refactor(tmp, unlist(levelslist[i]),
+      tmp <- refactor(tmp, unlist(levelslist[i], use.names = FALSE),
                       attr(levelslist[i], "names"))
     }
 
@@ -2234,7 +2234,7 @@ dfFindUniqueEuctrRecord <- function(
   # uses prefermemberstate and nms
   result <- lapply(nst,
                    function(x) removeMSversions(x))
-  result <- unlist(result)
+  result <- unlist(result, use.names = FALSE)
 
   # eleminate the unwanted EUCTR records
   df <- df[!(df[["_id"]] %in% result), ]
@@ -2433,7 +2433,7 @@ typeField <- function(dfi) {
 
   # prepare output
   if (!inherits(tmp, "try-error") &&
-      !is.null(unlist(tmp))) {
+      !is.null(unlist(tmp, use.names = FALSE))) {
 
     # need to construct new data frame,
     # since replacing columns with
